<?php

/**
 *
 * @copyright  2010 frasq.org
 * @version    1
 * @link       http://www.frasq.org
 */

function node_id($node) {
	if (!is_numeric($node)) {
		return false;
	}

	$tabnode=db_prefix_table('node');

	$sql="SELECT node_id FROM $tabnode WHERE node_id=$node LIMIT 1";

	$r = db_query($sql);

	return $r ? $r[0]['node_id'] : false;
}

function node_get($lang, $node_id, $strict=true) {
	$sqllang=db_sql_arg($lang, false);

	$join = $strict ? 'JOIN' : 'LEFT JOIN';

	$tabnode=db_prefix_table('node');
	$tabnodelocale=db_prefix_table('node_locale');

	$sql="SELECT nloc.name AS node_name, nloc.title AS node_title, nloc.abstract AS node_abstract, nloc.cloud AS node_cloud, n.user_id AS node_user, UNIX_TIMESTAMP(n.created) AS node_created, UNIX_TIMESTAMP(n.modified) AS node_modified FROM $tabnode n $join $tabnodelocale nloc ON nloc.node_id=n.node_id AND nloc.locale=$sqllang WHERE n.node_id=$node_id LIMIT 1";

	$r = db_query($sql);

	return $r ? $r[0] : false;
}

function node_set($lang, $node_id, $node_name, $node_title, $node_abstract, $node_cloud) {
	$tabnode=db_prefix_table('node');

	$sql="UPDATE $tabnode SET modified=NOW() WHERE node_id=$node_id LIMIT 1";
	$r = db_update($sql);

	if (!$r) {
		return false;
	}

	$sqllang=db_sql_arg($lang, false);
	$sqlname=db_sql_arg($node_name, true);
	$sqltitle=db_sql_arg($node_title, true);
	$sqlabstract=db_sql_arg($node_abstract, true, true);
	$sqlcloud=db_sql_arg($node_cloud, true, true);

	$tabnodelocale=db_prefix_table('node_locale');

	$sql="INSERT $tabnodelocale SET node_id=$node_id, locale=$sqllang, name=$sqlname, title=$sqltitle, abstract=$sqlabstract, cloud=$sqlcloud ON DUPLICATE KEY UPDATE node_id=LAST_INSERT_ID(node_id), locale=VALUES(locale), name=VALUES(name), title=VALUES(title), abstract=VALUES(abstract), cloud=VALUES(cloud)";

	$r = db_insert($sql);

	return $r;
}

function node_get_contents($lang, $node_id) {
	$sqllang=db_sql_arg($lang, false);

	$tabnodecontent=db_prefix_table('node_content');
	$tabcontenttext=db_prefix_table('content_text');
	$tabcontentinfile=db_prefix_table('content_infile');

	$sql="SELECT nc.content_id AS content_id, nc.content_type AS content_type, nc.number AS content_number, ct.text AS content_text, ct.eval AS content_eval, cin.path AS content_infile FROM $tabnodecontent nc LEFT JOIN $tabcontenttext ct ON nc.content_type='text' AND ct.content_id=nc.content_id AND ct.locale=$sqllang LEFT JOIN $tabcontentinfile cin ON nc.content_type='infile' AND cin.content_id=nc.content_id AND cin.locale=$sqllang WHERE nc.node_id=$node_id ORDER BY nc.number";

	$r = db_query($sql);

	return $r;
}

function node_set_contents($lang, $node_id, $node_contents) {
	$sqllang=db_sql_arg($lang, false);

	$tabnode=db_prefix_table('node');

	$sql="UPDATE $tabnode SET modified=NOW() WHERE node_id=$node_id LIMIT 1";

	$r = db_update($sql);

	if (!$r) {
		return false;
	}

	$number = 1;

	$tabnodecontent=db_prefix_table('node_content');
	$tabcontenttext=db_prefix_table('content_text');
	$tabcontentinfile=db_prefix_table('content_infile');

	foreach ($node_contents as $c) {
		$content_text='';
		$content_eval=false;
		$content_infile=false;

		extract($c);	/* content_id content_number content_type (content_text content_eval | content_infile) */
		$sqltype=db_sql_arg($content_type, false);

		$sql="UPDATE $tabnodecontent SET number=$number WHERE node_id=$node_id AND content_id=$content_id AND content_type=$sqltype";
		$r = db_update($sql);

		if (!$r) {
			return false;
		}

		switch($content_type) {
			case 'text':
				$sqltext=db_sql_arg($content_text, true, true);
				$sqleval=$content_eval ? 1 : 0;
				$sql="INSERT $tabcontenttext (content_id, locale, text, eval) VALUES ($content_id, $sqllang, $sqltext, $sqleval) ON DUPLICATE KEY UPDATE text=VALUES(text), eval=VALUES(eval)";
				break;
			case 'infile':
				$sqlpath=db_sql_arg($content_infile, true, true);
				$sql="INSERT $tabcontentinfile SET content_id=$content_id, locale=$sqllang, path=$sqlpath ON DUPLICATE KEY UPDATE path=VALUES(path)";
				break;
		}

		$r = db_update($sql);

		if (!$r) {
			return false;
		}

		$number++;
	}

	return true;
}

function node_create_content($lang, $node_id, $content_type, $content_number=0) {
	$tabnodecontent=db_prefix_table('node_content');

	$sql="SELECT COUNT(*)+1 AS n FROM $tabnodecontent WHERE node_id=$node_id";

	$r = db_query($sql);

	if (!$r) {
		return false;
	}

	$n = $r[0]['n'];

	if ($content_number < 1 or $content_number > $n) {
		$content_number = $n;
	}

	$sqllang=db_sql_arg($lang, false);

	switch($content_type) {
		case 'text':
		case 'infile':
			$tabcontenttype=db_prefix_table("content_$content_type");
			break;
		default:
			return false;
	}

	$sql="INSERT $tabcontenttype SET locale=$sqllang";

	$r = db_insert($sql);

	if (!$r) {
		return false;
	}

	$content_id = db_insert_id();

	if ($content_number != $n) {
		$sql="UPDATE $tabnodecontent SET number=number+1 WHERE node_id=$node_id AND number >= $content_number ORDER BY number";

		db_update($sql);
	}

	$sqltype=db_sql_arg($content_type, false);

	$sql="INSERT $tabnodecontent SET node_id=$node_id, content_id=$content_id, content_type=$sqltype, number=$content_number";

	$r = db_insert($sql);

	return $r ? compact('content_id', 'content_number') : false;
}

function node_delete_content($node_id, $content_id, $content_type) {
	$sqltype=db_sql_arg($content_type, false);

	switch($content_type) {
		case 'text':
		case 'infile':
			$tabnodecontent=db_prefix_table('node_content');
			$tabcontenttype=db_prefix_table("content_$content_type");

			$sql="DELETE nc, ct FROM $tabnodecontent nc JOIN $tabcontenttype ct ON ct.content_id=nc.content_id WHERE nc.node_id=$node_id AND nc.content_id=$content_id AND nc.content_type=$sqltype";
			break;
		default:
			return false;
	}

	$r = db_delete($sql);

	if (!$r) {
		return false;
	}

	$sql="SET @n=0";
	db_update($sql);
	$sql="UPDATE $tabnodecontent SET number=(@n:=@n+1) WHERE node_id=$node_id ORDER BY number";
	db_update($sql);

	return true;
}

